|
micro-test-plus 3.2.1
The µTest++ Testing Framework
|
#include <stdio.h>Go to the source code of this file.
Namespaces | |
| namespace | micro_os_plus |
| namespace | micro_os_plus::micro_test_plus |
| namespace | micro_os_plus::micro_test_plus::detail |
| Namespace with implementation details, not part of the public API. | |
Functions | |
| template<class T> | |
| constexpr auto | micro_os_plus::micro_test_plus::detail::get (const T &t) |
| Generic getter, calling the getter implementation. | |
| template<class T> | |
| constexpr auto | micro_os_plus::micro_test_plus::detail::get_impl (const T &t, int) -> decltype(t.get()) |
| Generic getter implementation. If the type has a get() method, call it. It is recommended for custom types to define a get() method. | |
| template<class T> | |
| constexpr auto | micro_os_plus::micro_test_plus::detail::get_impl (const T &t,...) -> decltype(auto) |
| Variadic getter implementation that returns the first argument and discards the rest. | |