|
micro-test-plus 3.2.1
The µTest++ Testing Framework
|
Operator to check if the expression does not throw any exception. More...
#include <micro-os-plus/micro-test-plus.h>
Inheritance diagram for micro_os_plus::micro_test_plus::detail::nothrow_< Callable_T >:Public Member Functions | |
| constexpr | nothrow_ (const Callable_T &func) |
| constexpr | operator bool () const |
Public Attributes | |
| const bool | value_ {} |
Operator to check if the expression does not throw any exception.
|
inlineexplicitconstexpr |
|
inlinenodiscardconstexpr |
| const bool micro_os_plus::micro_test_plus::detail::nothrow_< Callable_T >::value_ {} |