Go to the source code of this file.
|
| struct | micro_os_plus::micro_test_plus::type_traits::floating_point_constant< T, N, D, Size, P > |
| | A generic floating point constant, with custom size and precision. It has a getter and a '-' operator to return the negative value. More...
|
| |
| struct | micro_os_plus::micro_test_plus::type_traits::function_traits< R(*)(Args_T...)> |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::function_traits< R(Args_T...)> |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::function_traits< R(T::*)(Args_T...) const > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::function_traits< R(T::*)(Args_T...)> |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::genuine_integral_value< T > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::identity< T,... > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::integral_constant< N > |
| | A generic integral constant. It has a getter and a '-' operator to return the negative value. More...
|
| |
| struct | micro_os_plus::micro_test_plus::type_traits::list<... > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::op |
| | Empty base class of all operators. More...
|
| |
| struct | micro_os_plus::micro_test_plus::type_traits::requires_< bool > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::requires_< true > |
| |
| struct | micro_os_plus::micro_test_plus::type_traits::value< T, class > |
| | Class defining a generic value, accessible via a getter. More...
|
| |
| struct | micro_os_plus::micro_test_plus::type_traits::value< T, type_traits::requires_t< type_traits::is_floating_point_v< T > > > |
| | A generic value used to define floating points, which, in addition to the actual value, has an epsilon, to use the desired precision during comparisons. If missing, the default is 1 / (10^decimals). More...
|
| |